@@ -18,7 +18,9 @@
 Application::Application(int &argc, char **argv)
     : DApplication(argc, argv)
 {
+    qDebug() << "Initializing application";
     loadTranslator();
+    qDebug() << "Translations loaded";
     setAttribute(Qt::AA_UseHighDpiPixmaps);
     setApplicationName("deepin-reader");
     setOrganizationName("deepin");
@@ -32,9 +34,12 @@ Application::Application(int &argc, char **argv)
 
 Application::~Application()
 {
+    qDebug() << "Destroying application resources";
     PageRenderThread::destroyForever();
+    qDebug() << "Page render threads destroyed";
     DBusObject::destory();
-    qDebug() << __FUNCTION__ << "退出应用！";
+    qDebug() << "DBus object destroyed";
+    qInfo() << "Application exiting";
 }
 
 void Application::emitSheetChanged()
@@ -44,6 +49,7 @@ void Application::emitSheetChanged()
 
 void Application::handleQuitAction()
 {
+    qDebug() << "Handling quit action";
     QList<MainWindow *> list = MainWindow::m_list;
 
     //倒序退出,如果取消了则停止
@@ -61,6 +67,7 @@ bool Application::notify(QObject *object, QEvent *event)
         if ((object->inherits("QAbstractButton")) && (keyevent->key() == Qt::Key_Return || keyevent->key() == Qt::Key_Enter)) {
             QAbstractButton *pushButton = dynamic_cast<QAbstractButton *>(object);
             if (pushButton) {
+                qDebug() << "Simulating click for button:" << pushButton;
                 emit pushButton->clicked(!pushButton->isChecked());
                 return true;
             }
@@ -75,6 +82,7 @@ bool Application::notify(QObject *object, QEvent *event)
             // QPoint(0,0) 表示无法获取光标位置
             if (pos != QPoint(0, 0)) {
                 QMouseEvent event(QEvent::MouseButtonPress, pos, Qt::RightButton, Qt::NoButton, Qt::NoModifier);
+                qDebug() << "Simulating right click at position:" << pos;
                 QCoreApplication::sendEvent(object, &event);
             }
         }
@@ -94,6 +102,7 @@ bool Application::notify(QObject *object, QEvent *event)
             if (top_window->isWindow() && !top_window->property(NON_FIRST_ACTIVE).toBool()) {
                 top_window->setFocus();
                 top_window->setProperty(NON_FIRST_ACTIVE, true);
+                qDebug() << "Reset focus to top level window";
             }
         }
     }
@@ -104,6 +113,7 @@ bool Application::notify(QObject *object, QEvent *event)
     if (event->type() == QEvent::ZOrderChange ||
             event->type() == QEvent::WindowActivate) {
         if (DocSheet *doc = qobject_cast<DocSheet *>(object)) {
+            qDebug() << "Updating last operation file to:" << doc->filePath();
             DocSheet::g_lastOperationFile = doc->filePath();
         }
     }
