@@ -9,21 +9,25 @@
 #include "Application.h"
 
 #include <DGuiApplicationHelper>
+#include <QDebug>
 
 #include <QPainter>
 #include <QItemSelectionModel>
 #include <QAbstractItemView>
 #include <QPainterPath>
-
 SearchResDelegate::SearchResDelegate(QAbstractItemView *parent)
     : DStyledItemDelegate(parent)
 {
     m_parent = parent;
+    qDebug() << "SearchResDelegate created with parent:" << parent;
 }
 
+
 void SearchResDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
+    qDebug() << "Entering SearchResDelegate::paint() for row:" << index.row();
     if (index.isValid()) {
+        qDebug() << "Painting valid index for row:" << index.row();
         const QPixmap &pixmap = index.data(ImageinfoType_e::IMAGE_PIXMAP).value<QPixmap>();
         QSize pageSize = index.data(ImageinfoType_e::IMAGE_PAGE_SIZE).toSize();
 
@@ -105,11 +109,17 @@ void SearchResDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
         painter->setPen(QPen(DTK_NAMESPACE::Gui::DGuiApplicationHelper::instance()->applicationPalette().frameBorder().color(), bottomlineHeight));
         painter->drawLine(textStartX, option.rect.bottom() - bottomlineHeight, option.rect.right(), option.rect.bottom() - bottomlineHeight);
         painter->restore();
+    } else {
+        qWarning() << "Invalid index in SearchResDelegate::paint()";
     }
+    qDebug() << "Exiting SearchResDelegate::paint() for row:" << index.row();
 }
 
 QSize SearchResDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    return DStyledItemDelegate::sizeHint(option, index);
+    qDebug() << "Entering SearchResDelegate::sizeHint()";
+    QSize size = DStyledItemDelegate::sizeHint(option, index);
+    qDebug() << "Exiting SearchResDelegate::sizeHint(), returning size:" << size;
+    return size;
 }
 
